@@ -768,6 +768,16 @@ gedit_bookmarks_plugin_activate (GeditWindowActivatable *activatable)
 	install_messages (priv->window);
 }
 
+static void
+gedit_bookmarks_plugin_update_state (GeditWindowActivatable *activatable)
+{
+	GeditBookmarksPluginPrivate *priv;
+
+	priv = GEDIT_BOOKMARKS_PLUGIN (activatable)->priv;
+	gtk_action_group_set_sensitive (priv->action_group,
+					gedit_window_get_active_view (priv->window) != NULL);
+}
+
 static void
 save_bookmark_metadata (GeditView *view)
 {
@@ -886,23 +896,29 @@ on_delete_range (GtkTextBuffer *buffer,
 	GSList *marks;
 	GSList *item;
 
+	/* After deleting, all bookmarks from the deleted range are collapsed at start. */
 	iter = *start;
-
-	/* move to start of line */
-	gtk_text_iter_set_line_offset (&iter, 0);
-
-	/* remove any bookmarks that are collapsed on each other due to this */
-	marks = gtk_source_buffer_get_source_marks_at_iter (GTK_SOURCE_BUFFER (buffer),
-							    &iter,
+	marks = gtk_source_buffer_get_source_marks_at_line (GTK_SOURCE_BUFFER (buffer),
+							    gtk_text_iter_get_line (&iter),
 							    BOOKMARK_CATEGORY);
 
 	if (marks == NULL)
 		return;
 
-	/* remove all but the first mark */
+	/* Remove all but the first bookmark. */
 	for (item = marks->next; item; item = item->next)
 		gtk_text_buffer_delete_mark (buffer, GTK_TEXT_MARK (item->data));
 
+	/* Make sure it is at the beginning of the line again. */
+	if (gtk_text_iter_get_line_offset (&iter) != 0)
+	{
+		gtk_text_iter_set_line_offset (&iter, 0);
+
+		gtk_text_buffer_move_mark (buffer,
+					   GTK_TEXT_MARK (marks->data),
+					   &iter);
+	}
+
 	g_slist_free (marks);
 }
 
@@ -1082,6 +1098,11 @@ toggle_bookmark (GtkSourceBuffer *buffer,
 	GtkTextIter start;
 	GtkSourceMark *bookmark = NULL;
 
+	if (buffer == NULL)
+	{
+		return;
+	}
+
 	bookmark = get_bookmark_and_iter (buffer, iter, &start);
 
 	if (bookmark != NULL)
@@ -1101,6 +1122,7 @@ on_toggle_bookmark_activate (GtkAction            *action,
 	GtkSourceBuffer *buffer;
 
 	buffer = GTK_SOURCE_BUFFER (gedit_window_get_active_document (plugin->priv->window));
+
 	toggle_bookmark (buffer, NULL);
 }
 
@@ -1191,6 +1213,7 @@ gedit_window_activatable_iface_init (GeditWindowActivatableInterface *iface)
 {
 	iface->activate = gedit_bookmarks_plugin_activate;
 	iface->deactivate = gedit_bookmarks_plugin_deactivate;
+	iface->update_state = gedit_bookmarks_plugin_update_state;
 }
 
 G_MODULE_EXPORT void
