@@ -20,22 +20,14 @@
 #  Boston, MA 02110-1301, USA.
 
 import os
-from gi.repository import GObject, Gio
-import sys
-import bisect
-import types
-import shlex
-import re
-import os
+from gi.repository import GLib, GObject, Gio
 
-import module
-import method
-import result
-import exceptions
-import metamodule
+import sys, bisect, types, shlex, re, os, traceback
 
-from accel_group import AccelGroup
-from accel_group import Accelerator
+from . import module, method, result, exceptions, metamodule
+
+from commands.accel_group import AccelGroup
+from commands.accel_group import Accelerator
 
 __all__ = ['is_commander_module', 'Commands', 'Accelerator']
 
@@ -87,7 +79,9 @@ class Commands(Singleton):
             self.retval = None
 
         def autocomplete_func(self):
-            if self.retval == result.Result.PROMPT:
+            mod = sys.modules['commander.commands.result']
+
+            if self.retval == mod.Result.PROMPT:
                 return self.retval.autocomplete
             else:
                 return {}
@@ -111,7 +105,7 @@ class Commands(Singleton):
             if ret:
                 ct.retval = ct.generator.send(ret)
             else:
-                ct.retval = ct.generator.next()
+                ct.retval = next(ct.generator)
 
             return ct.retval
 
@@ -156,7 +150,7 @@ class Commands(Singleton):
         self._modules = None
 
         for k in self._timeouts:
-            GObject.source_remove(self._timeouts[k])
+            GLib.source_remove(self._timeouts[k])
 
         self._timeouts = {}
 
@@ -198,7 +192,7 @@ class Commands(Singleton):
 
         try:
             monitor = gfile.monitor_directory(Gio.FileMonitorFlags.NONE, None)
-        except Gio.Error, e:
+        except Gio.Error as e:
             # Could not create monitor, this happens on systems where file monitoring is
             # not supported, but we don't really care
             pass
@@ -258,11 +252,13 @@ class Commands(Singleton):
             self.scan(d)
 
     def _run_generator(self, state, ret=None):
+        mod = sys.modules['commander.commands.result']
+
         try:
             # Determine first use
             retval = state.run(ret)
 
-            if not retval or (isinstance(retval, result.Result) and (retval == result.DONE or retval == result.HIDE)):
+            if not retval or (isinstance(retval, mod.Result) and (retval == mod.DONE or retval == mod.HIDE)):
                 state.pop()
 
                 if state:
@@ -275,12 +271,12 @@ class Commands(Singleton):
 
             if state:
                 return self.run(state)
-        except Exception, e:
+        except Exception as e:
             # Something error like, we throw on the parent generator
             state.pop()
 
             if state:
-                state.top().generator.throw(type(e), e)
+                state.top().generator.throw(type(e), e, e.__traceback__)
             else:
                 # Re raise it for the top most to show the error
                 raise
@@ -288,13 +284,15 @@ class Commands(Singleton):
         return None
 
     def run(self, state, ret=None):
+        mod = sys.modules['commander.commands.result']
+
         if type(ret) == types.GeneratorType:
             # Ok, this is cool stuff, generators can ask and susped execution
             # of commands, for instance to prompt for some more information
             state.push(ret)
 
             return self._run_generator(state)
-        elif not isinstance(ret, result.Result) and len(state) > 1:
+        elif not isinstance(ret, mod.Result) and len(state) > 1:
             # Basicly, send it to the previous?
             state.pop()
 
@@ -393,7 +391,7 @@ class Commands(Singleton):
             del commander.modules.__dict__[mod.name]
 
     def reload_module(self, mod):
-        if isinstance(mod, basestring):
+        if isinstance(mod, str):
             mod = self.resolve_module(mod)
 
         if not mod or not self._modules:
@@ -405,9 +403,10 @@ class Commands(Singleton):
         # Now, try to reload the module
         try:
             mod.reload()
-        except Exception, e:
+        except Exception as e:
             # Reload failed, we remove the module
-            print 'Failed to reload module (%s):' % (mod.name,), e
+            info = traceback.format_tb(sys.exc_info()[2])
+            print('Failed to reload module ({0}):\n  {1}'.format(mod.name, info[-1]))
 
             self._modules.remove(mod)
             return
@@ -444,17 +443,17 @@ class Commands(Singleton):
                 return
 
             if path in self._timeouts:
-                GObject.source_remove(self._timeouts[path])
+                GLib.source_remove(self._timeouts[path])
 
             # We add a timeout because a common save strategy causes a
             # DELETE/CREATE event chain
-            self._timeouts[path] = GObject.timeout_add(500, self.on_timeout_delete, path, mod)
+            self._timeouts[path] = GLib.timeout_add(500, self.on_timeout_delete, path, mod)
         elif evnt == Gio.FileMonitorEvent.CREATED:
             path = gfile1.get_path()
 
             # Check if this CREATE followed a previous DELETE
             if path in self._timeouts:
-                GObject.source_remove(self._timeouts[path])
+                GLib.source_remove(self._timeouts[path])
                 del self._timeouts[path]
 
             # Reload the module
