@@ -19,11 +19,11 @@
 #  Foundation, Inc., 51 Franklin Street, Fifth Floor,
 #  Boston, MA 02110-1301, USA.
 
-import exceptions
+import commands.exceptions as exceptions
 import types
 import inspect
 import sys
-import commander.utils as utils
+import utils
 
 class Method:
     def __init__(self, method, name, parent):
@@ -118,10 +118,10 @@ class Method:
 
         return self.method(*args, **kwargs)
 
-    def __cmp__(self, other):
+    def __lt__(self, other):
         if isinstance(other, Method):
-            return cmp(self.name, other.name)
+            return self.name < other.name
         else:
-            return cmp(self.name, other)
+            return self.name < other
 
 # vi:ex:ts=4:et
