@@ -16,18 +16,15 @@
 #
 #  You should have received a copy of the GNU General Public License
 #  along with this program; if not, write to the Free Software
-#  Foundation, Inc., 59 Temple Place, Suite 330,
-#  Boston, MA 02111-1307, USA.
+#  Foundation, Inc., 51 Franklin Street, Fifth Floor,
+#  Boston, MA 02110-1301, USA.
 
-import sys
-import os
-import types
-import bisect
+import sys, os, types, bisect, importlib
 
 import utils
-import exceptions
-import method
-import rollbackimporter
+import commands.exceptions as exceptions
+import commands.method as method
+import commands.rollbackimporter as rollbackimporter
 
 class Module(method.Method):
     def __init__(self, base, mod, parent=None):
@@ -70,8 +67,8 @@ class Module(method.Method):
             else:
                 root = []
 
-            root = filter(lambda x: x in dic and type(dic[x]) == types.FunctionType, root)
-            self._roots = map(lambda x: method.Method(dic[x], x, self.mod), root)
+            root = list(filter(lambda x: x in dic and type(dic[x]) == types.FunctionType, root))
+            self._roots = list(map(lambda x: method.Method(dic[x], x, self.mod), root))
 
         return self._roots
 
@@ -128,8 +125,8 @@ class Module(method.Method):
             sys.path.insert(0, self._dirname)
 
             self._rollback.monitor()
-            self.mod = __import__(self.real_name, globals(), locals(), [], 0)
             self._rollback.cancel()
+            self.mod = importlib.import_module(self.real_name)
 
             if not utils.is_commander_module(self.mod):
                 raise Exception('Module is not a commander module...')
