@@ -60,7 +60,7 @@ class Entry(Gtk.EventBox):
         self._entry.show()
 
         css = Gtk.CssProvider()
-        css.load_from_data("""
+        css.load_from_data(bytes("""
 @binding-set terminal-like-bindings {
     unbind "<Control>A";
 
@@ -81,8 +81,9 @@ GtkEntry#gedit-commander-entry {
     background: transparent;
     border-width: 0;
     box-shadow: 0 0 transparent;
+    transition: none;
 }
-""")
+""", 'utf-8'))
 
         # FIXME: remove hardcopy of 600 (GTK_STYLE_PROVIDER_PRIORITY_APPLICATION)
         # https://bugzilla.gnome.org/show_bug.cgi?id=646860
@@ -358,7 +359,7 @@ GtkEntry#gedit-commander-entry {
 
     def on_suspend_resume(self):
         if self._wait_timeout:
-            GObject.source_remove(self._wait_timeout)
+            GLib.source_remove(self._wait_timeout)
             self._wait_timeout = 0
         else:
             self._cancel_button.destroy()
@@ -389,7 +390,7 @@ GtkEntry#gedit-commander-entry {
 
         try:
             ret = cb()
-        except Exception, e:
+        except Exception as e:
             self.command_history_done()
             self._command_state.clear()
 
@@ -403,20 +404,22 @@ GtkEntry#gedit-commander-entry {
 
             return None
 
-        if ret == commands.result.Result.SUSPEND:
+        mod = sys.modules['commander.commands.result']
+
+        if ret == mod.Result.SUSPEND:
             # Wait for it...
             self._suspended = ret
             ret.register(self.on_suspend_resume)
 
-            self._wait_timeout = GObject.timeout_add(500, self._show_wait_cancel)
+            self._wait_timeout = GLib.timeout_add(500, self._show_wait_cancel)
             self._entry.set_sensitive(False)
         else:
             self.command_history_done()
             self.prompt('')
 
-            if ret == commands.result.Result.PROMPT:
+            if ret == mod.Result.PROMPT:
                 self.prompt(ret.prompt)
-            elif (ret == None or ret == commands.result.HIDE) and not self._prompt and (not self._info_window or self._info_window.empty()):
+            elif (ret == None or ret == mod.HIDE) and not self._prompt and (not self._info_window or self._info_window.empty()):
                 self._command_state.clear()
                 self._view.grab_focus()
                 self.destroy()
@@ -494,7 +497,7 @@ GtkEntry#gedit-commander-entry {
         #  * "hello world|"
         posidx = None
 
-        for idx in xrange(0, len(words)):
+        for idx in range(0, len(words)):
             spec = self._complete_word_match(words[idx])
 
             if words[idx].start(0) > pos:
@@ -550,7 +553,7 @@ GtkEntry#gedit-commander-entry {
 
             # Remove system arguments
             s = ['argstr', 'args', 'entry', 'view']
-            args = filter(lambda x: not x in s, args)
+            args = list(filter(lambda x: not x in s, args))
 
             if realidx < len(args):
                 arg = args[realidx]
@@ -577,15 +580,15 @@ GtkEntry#gedit-commander-entry {
                 }
 
                 if not spec.keywords:
-                    for k in kwargs.keys():
+                    for k in list(kwargs.keys()):
                         if not k in spec.args:
                             del kwargs[k]
 
                 ret = func(**kwargs)
-            except Exception, e:
+            except Exception as e:
                 # Can be number of arguments, or return values or simply buggy
                 # modules
-                print e
+                print(e)
                 traceback.print_exc()
                 return True
 
