@@ -881,7 +881,7 @@ static const SECTION union { const guint8 data[6976]; const double alignment; vo
   0x29, 0x75, 0x69, 0x2f, 0x06, 0x00, 0x00, 0x00
 } };
 
-static GStaticResource static_resource = { gedit_drawspaces_resource_data.data, sizeof (gedit_drawspaces_resource_data.data) };
+static GStaticResource static_resource = { gedit_drawspaces_resource_data.data, sizeof (gedit_drawspaces_resource_data.data), NULL, NULL, NULL };
 extern GResource *gedit_drawspaces_get_resource (void);
 GResource *gedit_drawspaces_get_resource (void)
 {
