@@ -17,6 +17,7 @@
 #  Foundation, Inc., 59 Temple Place, Suite 330,
 #  Boston, MA 02111-1307, USA.
 
-from .viewactivatable import GitPlugin
+from .viewactivatable import GitViewActivatable
+from .windowactivatable import GitWindowActivatable
 
 # ex:ts=4:et:
